@@ -21,7 +21,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-  #include <cheese-config.h>
+  #include <config.h>
 #endif
 
 #include <glib.h>
