@@ -42,11 +42,6 @@ enum
 
 static GParamSpec *properties[PROP_LAST];
 
-G_DEFINE_TYPE (CheeseEffect, cheese_effect, G_TYPE_OBJECT)
-
-#define CHEESE_EFFECT_GET_PRIVATE(o) \
-  (G_TYPE_INSTANCE_GET_PRIVATE ((o), CHEESE_TYPE_EFFECT, CheeseEffectPrivate))
-
 struct _CheeseEffectPrivate
 {
   gchar *name;
@@ -54,6 +49,8 @@ struct _CheeseEffectPrivate
   GstElement *control_valve;
 };
 
+G_DEFINE_TYPE_WITH_PRIVATE (CheeseEffect, cheese_effect, G_TYPE_OBJECT)
+
 static void
 cheese_effect_get_property (GObject *object, guint property_id,
                             GValue *value, GParamSpec *pspec)
@@ -103,15 +100,30 @@ cheese_effect_set_property (GObject *object, guint property_id,
   }
 }
 
+static void
+cheese_effect_finalize (GObject *object)
+{
+    CheeseEffect *effect;
+    CheeseEffectPrivate *priv;
+
+    effect = CHEESE_EFFECT (object);
+    priv = effect->priv;
+
+    g_clear_pointer (&priv->name, g_free);
+    g_clear_pointer (&priv->pipeline_desc, g_free);
+    g_clear_pointer (&priv->control_valve, gst_object_unref);
+
+    G_OBJECT_CLASS (cheese_effect_parent_class)->finalize (object);
+}
+
 static void
 cheese_effect_class_init (CheeseEffectClass *klass)
 {
   GObjectClass *object_class = G_OBJECT_CLASS (klass);
 
-  g_type_class_add_private (klass, sizeof (CheeseEffectPrivate));
-
   object_class->get_property = cheese_effect_get_property;
   object_class->set_property = cheese_effect_set_property;
+  object_class->finalize = cheese_effect_finalize;
 
   /**
    * CheeseEffect:name:
@@ -235,7 +247,7 @@ cheese_effect_disable_preview (CheeseEffect *effect)
 static void
 cheese_effect_init (CheeseEffect *self)
 {
-  self->priv = CHEESE_EFFECT_GET_PRIVATE (self);
+  self->priv = cheese_effect_get_instance_private (self);
 }
 
 /**
