@@ -20,7 +20,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-  #include "cheese-config.h"
+  #include "config.h"
 #endif
 
 #include <glib.h>
@@ -735,6 +735,8 @@ cheese_thumb_view_constructed (GObject *object)
   CheeseThumbView *thumb_view = CHEESE_THUMB_VIEW (object);
   CheeseThumbViewPrivate *priv = cheese_thumb_view_get_instance_private (thumb_view);
   
+  G_OBJECT_CLASS (cheese_thumb_view_parent_class)->constructed (object);
+
   gtk_icon_view_set_model (GTK_ICON_VIEW (thumb_view), GTK_TREE_MODEL (priv->store));
 
   gtk_widget_set_size_request (GTK_WIDGET (thumb_view),
@@ -780,6 +782,9 @@ cheese_thumb_view_set_vertical (CheeseThumbView *thumb_view, gboolean vertical)
     gtk_icon_view_set_columns(GTK_ICON_VIEW (thumb_view), priv->n_items);
   else
     gtk_icon_view_set_columns(GTK_ICON_VIEW (thumb_view), 1);
+
+  gtk_widget_set_hexpand (GTK_WIDGET (thumb_view), !vertical);
+  gtk_widget_set_vexpand (GTK_WIDGET (thumb_view), vertical);
 }
 
 void
